@@ -49,8 +49,10 @@ GType		ev_view_get_type	    (void) G_GNUC_CONST;
 GtkWidget*	ev_view_new		    (void);
 void		ev_view_set_model	    (EvView          *view,
 					     EvDocumentModel *model);
+EV_DEPRECATED
 void 		ev_view_set_loading         (EvView 	     *view,
 					     gboolean         loading);
+gboolean        ev_view_is_loading          (EvView          *view);
 void            ev_view_reload              (EvView          *view);
 void            ev_view_set_page_cache_size (EvView          *view,
 					     gsize            cache_size);
