@@ -643,12 +643,31 @@ static void
 ev_sidebar_init_icon_view (EvSidebarThumbnails *ev_sidebar_thumbnails)
 {
 	EvSidebarThumbnailsPrivate *priv;
+        GtkCellRenderer *renderer;
 
 	priv = ev_sidebar_thumbnails->priv;
 
 	priv->icon_view = gtk_icon_view_new_with_model (GTK_TREE_MODEL (priv->list_store));
-	gtk_icon_view_set_markup_column (GTK_ICON_VIEW (priv->icon_view), 0);
-	gtk_icon_view_set_pixbuf_column (GTK_ICON_VIEW (priv->icon_view), 1);
+
+        renderer = g_object_new (GTK_TYPE_CELL_RENDERER_PIXBUF,
+                                 "xalign", 0.5,
+                                 "yalign", 1.0,
+                                 NULL);
+        gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (priv->icon_view), renderer, FALSE);
+        gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (priv->icon_view),
+                                        renderer, "pixbuf", 1, NULL);
+
+        renderer = g_object_new (GTK_TYPE_CELL_RENDERER_TEXT,
+                                 "alignment", PANGO_ALIGN_CENTER,
+                                 "wrap-mode", PANGO_WRAP_WORD_CHAR,
+                                 "xalign", 0.5,
+                                 "yalign", 0.0,
+                                 "width", THUMBNAIL_WIDTH,
+                                 "wrap-width", THUMBNAIL_WIDTH,
+                                 NULL);
+        gtk_cell_layout_pack_end (GTK_CELL_LAYOUT (priv->icon_view), renderer, FALSE);
+        gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (priv->icon_view),
+                                        renderer, "markup", 0, NULL);
 	g_signal_connect (priv->icon_view, "selection-changed",
 			  G_CALLBACK (ev_sidebar_icon_selection_changed), ev_sidebar_thumbnails);
 
